# Generated by roxygen2: do not edit by hand

export(bind_indicators)
export(dsi_flextable_defaults)
export(geomean)
export(ggpie)
export(gho_clean)
export(gho_count)
export(gho_coverage)
export(gho_data)
export(gho_dimensions)
export(gho_has_data)
export(gho_indicators)
export(iso3_to_m49)
export(iso3_to_region)
export(m49_to_iso3)
export(scale_x_dsi_col)
export(scale_y_dsi_col)
export(sdg_areas)
export(sdg_clean)
export(sdg_coverage)
export(sdg_data)
export(sdg_goals)
export(sdg_indicators)
export(sdg_targets)
export(theme_dsi)
export(theme_dsi_facet)
importFrom(rlang,"%||%")
importFrom(rlang,.data)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
